# Zmei Gorynich

Intuitive web-framework, based on rock-solid opensource components.

[![Circle CI](https://circleci.com/gh/Negative Space OU/zmei/tree/develop.svg?style=svg)](https://circleci.com/gh/Negative Space OU/zmei/tree/develop)
